@@ -32,12 +32,20 @@ Puppet::Type.newtype(:neutron_network) do
     end
   end
 
+  newparam(:project_name) do
+    desc 'The name of the project which will own the network.(DEPRECATED)'
+  end
+
+  newproperty(:project_id) do
+    desc 'A uuid identifying the project which will own the network.(DEPRECATED)'
+  end
+
   newparam(:tenant_name) do
-    desc 'The name of the tenant which will own the network.'
+    desc 'The name of the tenant which will own the network.(DEPRECATED)'
   end
 
   newproperty(:tenant_id) do
-    desc 'A uuid identifying the tenant which will own the network.'
+    desc 'A uuid identifying the tenant which will own the network.(DEPRECATED)'
   end
 
   newproperty(:provider_network_type) do
@@ -79,16 +87,30 @@ Puppet::Type.newtype(:neutron_network) do
   end
 
   autorequire(:keystone_tenant) do
-    [self[:tenant_name]] if self[:tenant_name]
+    if self[:tenant_name]
+      [self[:tenant_name]]
+    else
+      [self[:project_name]] if self[:project_name]
+    end
   end
 
   validate do
     if self[:ensure] != :present
       return
     end
-    if self[:tenant_id] && self[:tenant_name]
+
+    if self[:tenant_id]
+      warning('The tenant_id property is deprecated. Use project_id.')
+    end
+    if self[:tenant_name]
+      warning('The tenant_name property is deprecated. Use project_name.')
+    end
+
+    project_id = self[:tenant_id] or self[:project_id]
+    project_name = self[:tenant_name] or self[:project_name]
+    if project_id && project_name
       raise(Puppet::Error, <<-EOT
-Please provide a value for only one of tenant_name and tenant_id.
+Please provide a value for only one of project_name and project_id.
 EOT
             )
     end
