@@ -23,7 +23,7 @@ describe 'neutron::agents::dhcp' do
     }
   end
 
-  shared_examples 'neutron dhcp agent' do
+  shared_examples 'neutron::agents::dhcp' do
     let :p do
       default_params.merge(params)
     end
@@ -45,6 +45,7 @@ describe 'neutron::agents::dhcp' do
       should contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_enable_addr6_list').with_value('<SERVICE DEFAULT>');
       should contain_neutron_dhcp_agent_config('agent/availability_zone').with_value('<SERVICE DEFAULT>');
       should contain_neutron_dhcp_agent_config('agent/report_interval').with_value('<SERVICE DEFAULT>');
+      should contain_neutron_dhcp_agent_config('DEFAULT/rpc_response_max_timeout').with_value('<SERVICE DEFAULT>');
       should contain_neutron_dhcp_agent_config('OVS/ovsdb_connection').with_value('<SERVICE DEFAULT>');
       should contain_neutron_dhcp_agent_config('OVS/integration_bridge').with_value('<SERVICE DEFAULT>');
       should contain_neutron_dhcp_agent_config('OVS/ssl_key_file').with_value('<SERVICE DEFAULT>');
@@ -52,7 +53,7 @@ describe 'neutron::agents::dhcp' do
       should contain_neutron_dhcp_agent_config('OVS/ssl_ca_cert_file').with_value('<SERVICE DEFAULT>');
     end
 
-    it 'installs neutron dhcp agent package' do
+    it 'installs neutron-dhcp-agent package' do
       if platform_params.has_key?(:dhcp_agent_package)
         should contain_package('neutron-dhcp-agent').with(
           :name   => platform_params[:dhcp_agent_package],
@@ -69,7 +70,7 @@ describe 'neutron::agents::dhcp' do
       end
     end
 
-    it 'configures neutron dhcp agent service' do
+    it 'configures neutron-dhcp-agent service' do
       should contain_service('neutron-dhcp-service').with(
         :name    => platform_params[:dhcp_agent_service],
         :enable  => true,
@@ -90,8 +91,8 @@ describe 'neutron::agents::dhcp' do
       before :each do
         params.merge!(:manage_service => false)
       end
-      it 'should not start/stop service' do
-        should contain_service('neutron-dhcp-service').without_ensure
+      it 'should not manage the service' do
+        should_not contain_service('neutron-dhcp-service')
       end
     end
 
@@ -180,49 +181,35 @@ describe 'neutron::agents::dhcp' do
       end
     end
 
-    context 'when enabling dhcp-host entry with list of addresses' do
+    context 'with dnsmasq parameters' do
       before :each do
-        params.merge!(:dnsmasq_enable_addr6_list => true)
+        params.merge!({
+          :dnsmasq_config_file       => '/foo',
+          :dnsmasq_dns_servers       => ['192.0.2.11', '192.0.2.12'],
+          :dnsmasq_base_log_dir      => '/var/log/neutron',
+          :dnsmasq_local_resolv      => true,
+          :dnsmasq_lease_max         => 16777216,
+          :dnsmasq_enable_addr6_list => false,
+        })
       end
-      it 'should enabling dhcp-host entry with list of addresses' do
-        should contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_enable_addr6_list').with_value('true');
+
+      it 'should configure the dnsmasq parameters' do
+        should contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_config_file')\
+          .with_value(params[:dnsmasq_config_file])
+        should contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_dns_servers')\
+          .with_value(params[:dnsmasq_dns_servers].join(','))
+        should contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_base_log_dir')\
+          .with_value(params[:dnsmasq_base_log_dir])
+        should contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_local_resolv')\
+          .with_value(params[:dnsmasq_local_resolv])
+        should contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_lease_max')\
+          .with_value(params[:dnsmasq_lease_max])
+        should contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_enable_addr6_list')\
+          .with_value(params[:dnsmasq_enable_addr6_list]);
       end
     end
   end
 
-  shared_examples 'neutron dhcp agent with dnsmasq_config_file specified' do
-    before do
-      params.merge!(
-        :dnsmasq_config_file => '/foo'
-      )
-    end
-    it 'configures dnsmasq_config_file' do
-      should contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_config_file').with_value(params[:dnsmasq_config_file])
-    end
-  end
-
-  shared_examples 'enable advertisement of the DNS resolver on the host.' do
-    before do
-      params.merge!(
-        :dnsmasq_local_resolv => true
-      )
-    end
-    it 'configures dnsmasq_local_resolv' do
-      should contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_local_resolv').with_value(params[:dnsmasq_config_file])
-    end
-  end
-
-  shared_examples 'neutron dhcp agent with dnsmasq_dns_servers set' do
-    before do
-      params.merge!(
-        :dnsmasq_dns_servers => ['1.2.3.4','5.6.7.8']
-      )
-    end
-    it 'should set dnsmasq_dns_servers' do
-      should contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_dns_servers').with_value(params[:dnsmasq_dns_servers].join(','))
-    end
-  end
-
   shared_examples 'neutron::agents::dhcp on Debian' do
     it 'configures subscription to neutron-dhcp-agent package' do
       should contain_service('neutron-dhcp-service').that_subscribes_to('Anchor[neutron::service::begin]')
@@ -251,9 +238,7 @@ describe 'neutron::agents::dhcp' do
         end
       end
 
-      it_behaves_like 'neutron dhcp agent'
-      it_behaves_like 'neutron dhcp agent with dnsmasq_config_file specified'
-      it_behaves_like 'neutron dhcp agent with dnsmasq_dns_servers set'
+      it_behaves_like 'neutron::agents::dhcp'
 
       if facts[:osfamily] == 'Debian'
         it_behaves_like 'neutron::agents::dhcp on Debian'
