@@ -60,6 +60,7 @@ describe 'neutron::agents::metering' do
       should contain_neutron_metering_agent_config('DEFAULT/driver').with_value(p[:driver]);
       should contain_neutron_metering_agent_config('DEFAULT/measure_interval').with_value('<SERVICE DEFAULT>');
       should contain_neutron_metering_agent_config('DEFAULT/report_interval').with_value('<SERVICE DEFAULT>');
+      should contain_neutron_metering_agent_config('DEFAULT/rpc_response_max_timeout').with_value('<SERVICE DEFAULT>');
     end
 
     it 'installs neutron metering agent package' do
@@ -90,8 +91,8 @@ describe 'neutron::agents::metering' do
         params.merge!(:manage_service => false)
       end
 
-      it 'should not start/stop service' do
-        should contain_service('neutron-metering-service').without_ensure
+      it 'should not manage the service' do
+        should_not contain_service('neutron-metering-service')
       end
     end
 
