@@ -16,9 +16,17 @@ describe 'neutron::designate' do
         should contain_neutron_config('DEFAULT/external_dns_driver').with_value('designate')
         should contain_neutron_config('designate/url').with_value('http://ip/designate')
         should contain_neutron_config('designate/password').with_value('secret').with_secret(true)
-        should contain_neutron_config('designate/username').with_value('neutron')
         should contain_neutron_config('designate/auth_type').with_value('password')
+        should contain_neutron_config('designate/username').with_value('neutron')
+        should contain_neutron_config('designate/user_domain_name').with_value('Default')
         should contain_neutron_config('designate/project_name').with_value('services')
+        should contain_neutron_config('designate/project_domain_name').with_value('Default')
+        should contain_neutron_config('designate/system_scope').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_config('designate/auth_url').with_value('http://127.0.0.1:5000')
+        should contain_neutron_config('designate/allow_reverse_dns_lookup').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_config('designate/ipv4_ptr_zone_prefix_size').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_config('designate/ipv6_ptr_zone_prefix_size').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_config('designate/ptr_zone_email').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -27,10 +35,10 @@ describe 'neutron::designate' do
         req_params.merge!({
           :auth_type                 => 'token',
           :username                  => 'user',
+          :user_domain_name          => 'Domain2',
           :project_id                => 'id1',
           :project_name              => 'proj',
           :project_domain_name       => 'Domain1',
-          :user_domain_name          => 'Domain2',
           :auth_url                  => 'http://auth/',
           :allow_reverse_dns_lookup  => false,
           :ipv4_ptr_zone_prefix_size => 765,
@@ -43,12 +51,13 @@ describe 'neutron::designate' do
         should contain_neutron_config('DEFAULT/external_dns_driver').with_value('designate')
         should contain_neutron_config('designate/url').with_value('http://ip/designate')
         should contain_neutron_config('designate/password').with_value('secret').with_secret(true)
-        should contain_neutron_config('designate/username').with_value('user')
         should contain_neutron_config('designate/auth_type').with_value('token')
+        should contain_neutron_config('designate/username').with_value('user')
+        should contain_neutron_config('designate/user_domain_name').with_value('Domain2')
         should contain_neutron_config('designate/project_id').with_value('id1')
         should contain_neutron_config('designate/project_name').with_value('proj')
         should contain_neutron_config('designate/project_domain_name').with_value('Domain1')
-        should contain_neutron_config('designate/user_domain_name').with_value('Domain2')
+        should contain_neutron_config('designate/system_scope').with_value('<SERVICE DEFAULT>')
         should contain_neutron_config('designate/auth_url').with_value('http://auth/')
         should contain_neutron_config('designate/allow_reverse_dns_lookup').with_value(false)
         should contain_neutron_config('designate/ipv4_ptr_zone_prefix_size').with_value(765)
@@ -56,6 +65,24 @@ describe 'neutron::designate' do
         should contain_neutron_config('designate/ptr_zone_email').with_value('foo@example.com')
       end
     end
+
+    context 'with system_scope' do
+      let :params do
+        req_params.merge!({
+          :project_id          => 'id1',
+          :project_name        => 'proj',
+          :project_domain_name => 'Domain1',
+          :system_scope        => 'all',
+        })
+      end
+
+      it 'configures designate in neutron.conf' do
+        should contain_neutron_config('designate/project_id').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_config('designate/project_name').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_config('designate/project_domain_name').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_config('designate/system_scope').with_value('all')
+      end
+    end
   end
 
   on_supported_os({
